from setuptools import find_packages, setup

setup(
    name="creyPY",
    version="0.0.1",
    description="My collection of Python and FastAPI shortcuts etc. ",
    author="Conrad Großer",
    author_email="conrad@noah.tech",
    packages=find_packages(),
    python_requires=">=3.12",
)
